Faucet Documentation
====================


Viewing documentation
---------------------

Docs are viewable on `readthedocs <https://faucet.readthedocs.io>`_.

Building documentation
----------------------

.. code:: console

  sudo pip3 install -r requirements.txt
  make html
